@@ -11,7 +11,7 @@ from collections.abc import Callable, Generator
 from io import StringIO
 from signal import SIGINT, signal
 from types import TracebackType
-from typing import Any, Self, Type
+from typing import Any, Self
 from urllib.parse import parse_qs, urlencode, urlparse
 
 import jsonschema
@@ -415,7 +415,7 @@ class KubeAPIVersion(Version):
         return self.vstring
 
     def __repr__(self):
-        return "KubeAPIVersion ('{0}')".format(str(self))
+        return f"KubeAPIVersion ('{str(self)}')"
 
     def _cmp(self, other):
         if isinstance(other, str):
@@ -759,7 +759,7 @@ class Resource(ResourceConstants):
             if not self.clean_up():
                 raise ResourceTeardownError(resource=self)
 
-    def _sigint_handler(self, signal_received: int, frame: Any) -> None:
+    def _sigint_handler(self, signal_received: int, _frame: Any) -> None:
         self.__exit__()
         sys.exit(signal_received)
 
@@ -1129,7 +1129,7 @@ class Resource(ResourceConstants):
 
         except TimeoutExpiredError as exp:
             if exp.last_exp:
-                raise exp.last_exp
+                raise exp.last_exp from exp
 
             raise
 
@@ -1163,13 +1163,7 @@ class Resource(ResourceConstants):
             dyn_client = get_client(config_file=config_file, context=context)
 
         def _get() -> Generator["Resource|ResourceInstance", None, None]:
-            _resources = cls._prepare_resources(
-                # type: ignore[misc]
-                dyn_client=dyn_client,
-                singular_name=singular_name,
-                *args,
-                **kwargs,
-            )
+            _resources = cls._prepare_resources(*args, dyn_client=dyn_client, singular_name=singular_name, **kwargs)  # type: ignore[misc]
             try:
                 for resource_field in _resources.items:
                     if raw:
@@ -1517,7 +1511,7 @@ class Resource(ResourceConstants):
             error_msg = SchemaValidator.format_validation_error(
                 error=e, kind=self.kind, name=self.name or "unnamed", api_group=self.api_group
             )
-            raise ValidationError(error_msg)
+            raise ValidationError(error_msg) from e
         except Exception as e:
             LOGGER.error(f"Unexpected error during validation: {e}")
             raise
@@ -1544,7 +1538,7 @@ class Resource(ResourceConstants):
             error_msg = SchemaValidator.format_validation_error(
                 error=e, kind=cls.kind, name=name, api_group=cls.api_group
             )
-            raise ValidationError(error_msg)
+            raise ValidationError(error_msg) from e
         except Exception as e:
             LOGGER.error(f"Unexpected error during validation: {e}")
             raise
@@ -1611,13 +1605,7 @@ class NamespacedResource(Resource):
             dyn_client = get_client(config_file=config_file, context=context)
 
         def _get() -> Generator["NamespacedResource|ResourceInstance", None, None]:
-            _resources = cls._prepare_resources(
-                # type: ignore[misc]
-                dyn_client=dyn_client,
-                singular_name=singular_name,
-                *args,
-                **kwargs,
-            )
+            _resources = cls._prepare_resources(*args, dyn_client=dyn_client, singular_name=singular_name, **kwargs)  # type: ignore[misc]
             try:
                 for resource_field in _resources.items:
                     if raw:
@@ -1665,7 +1653,7 @@ class NamespacedResource(Resource):
             raise MissingRequiredArgumentError(argument="namespace")
 
     def to_dict(self) -> None:
-        super(NamespacedResource, self)._base_body()
+        super()._base_body()
         self._base_body()
 
 
@@ -1950,7 +1938,7 @@ class BaseResourceList(ABC):
         return all(resource.clean_up(wait=wait) for resource in reversed(self.resources))
 
     @abstractmethod
-    def _create_resources(self, resource_class: Type, **kwargs: Any) -> None:
+    def _create_resources(self, resource_class: type, **kwargs: Any) -> None:
         """Abstract method to create resources based on specific logic."""
         pass
 
@@ -1965,7 +1953,7 @@ class ResourceList(BaseResourceList):
 
     def __init__(
         self,
-        resource_class: Type[Resource],
+        resource_class: type[Resource],
         num_resources: int,
         client: DynamicClient,
         **kwargs: Any,
@@ -1985,7 +1973,7 @@ class ResourceList(BaseResourceList):
         self.num_resources = num_resources
         self._create_resources(resource_class, **kwargs)
 
-    def _create_resources(self, resource_class: Type[Resource], **kwargs: Any) -> None:
+    def _create_resources(self, resource_class: type[Resource], **kwargs: Any) -> None:
         """Creates N resources with indexed names."""
         base_name = kwargs["name"]
 
@@ -2008,7 +1996,7 @@ class NamespacedResourceList(BaseResourceList):
 
     def __init__(
         self,
-        resource_class: Type[NamespacedResource],
+        resource_class: type[NamespacedResource],
         namespaces: ResourceList,
         client: DynamicClient,
         **kwargs: Any,
@@ -2032,7 +2020,7 @@ class NamespacedResourceList(BaseResourceList):
         self.namespaces = namespaces
         self._create_resources(resource_class, **kwargs)
 
-    def _create_resources(self, resource_class: Type[NamespacedResource], **kwargs: Any) -> None:
+    def _create_resources(self, resource_class: type[NamespacedResource], **kwargs: Any) -> None:
         """Creates one resource per namespace."""
         for ns in self.namespaces:
             instance = resource_class(
